﻿#region Copyright Syncfusion Inc. 2001 - 2016
// Copyright Syncfusion Inc. 2001 - 2016. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using Syncfusion.EJ.Export;
using Syncfusion.JavaScript.Models;
using Syncfusion.JavaScript;
using Syncfusion.XlsIO;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Configuration;
using System.Data.SqlClient;
using System.Web.Script.Serialization;

namespace SpreadsheetSample.Controllers
{
    public class HomeController : Controller
    {
        private string connetionString = ConfigurationManager.ConnectionStrings["SpreadDBConnectionString"].ConnectionString;
        public ActionResult Index()
        {
            var dataSource = GetDataFromDB();
            ViewBag.DataSource = dataSource;
            ViewBag.RowCount = dataSource.Count();
            return View();
        }
        private List<Customer> GetDataFromDB()
        {
            List<Customer> customers = new List<Customer>();
            SqlConnection sqlCon = new SqlConnection(connetionString);
            SqlCommand sqlComm = new SqlCommand("SELECT * FROM [dbo].[Table]", sqlCon);
            sqlCon.Open();
            SqlDataReader sqlDR = sqlComm.ExecuteReader();
            while (sqlDR.Read())
            {
                Customer customer = new Customer();
                customer.CustomerID = (int)sqlDR.GetValue(0);
                customer.CompanyName = sqlDR.GetValue(1).ToString();
                customer.ContactName = sqlDR.GetValue(2).ToString();
                customer.ContactTitle = sqlDR.GetValue(3).ToString();
                customer.Address = sqlDR.GetValue(4).ToString();
                customer.City = sqlDR.GetValue(5).ToString();
                customer.Region = sqlDR.GetValue(6).ToString();
                customer.PostalCode = sqlDR.GetValue(7).ToString();
                customer.Country = sqlDR.GetValue(8).ToString();
                customer.Phone = sqlDR.GetValue(9).ToString();
                customers.Add(customer);
            }
            sqlCon.Close();
            return customers;
        }
        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult SaveChangesToDatabase(string editedValues)
        {
            JavaScriptSerializer serialize = new JavaScriptSerializer();
            List<Customer> editedData = serialize.Deserialize<List<Customer>>(editedValues);

            SqlConnection sqlCon = new SqlConnection(connetionString);
            sqlCon.Open();
            for (int i = 0; i < editedData.Count; i++)
            {
                var customer = editedData[i];
                SqlCommand selectComm = new SqlCommand("SELECT * FROM [dbo].[Table] WHERE [CustomerID] = '" + customer.CustomerID + "'", sqlCon);
                var hasFileInDB = selectComm.ExecuteScalar();
                if (hasFileInDB == null)
                {
                    SqlCommand sqlComm = new SqlCommand("INSERT INTO [dbo].[Table]([CustomerID], [CompanyName], [ContactName], [ContactTitle], [Address], [City], [Region], [PostalCode], [Country], [Phone]) VALUES (@CustomerID, @CompanyName, @ContactName, @ContactTitle, @Address, @City, @Region, @PostalCode, @Country, @Phone)", sqlCon);
                    sqlComm.Parameters.AddWithValue("@CustomerID", customer.CustomerID);
                    sqlComm.Parameters.AddWithValue("@CompanyName", customer.CompanyName ?? "");
                    sqlComm.Parameters.AddWithValue("@ContactName", customer.ContactName ?? "");
                    sqlComm.Parameters.AddWithValue("@ContactTitle", customer.ContactTitle ?? "");
                    sqlComm.Parameters.AddWithValue("@Address", customer.Address ?? "");
                    sqlComm.Parameters.AddWithValue("@City", customer.City ?? "");
                    sqlComm.Parameters.AddWithValue("@Region", customer.Region ?? "");
                    sqlComm.Parameters.AddWithValue("@PostalCode", customer.PostalCode ?? "");
                    sqlComm.Parameters.AddWithValue("@Country", customer.Country ?? "");
                    sqlComm.Parameters.AddWithValue("@Phone", customer.Phone ?? "");
                    sqlComm.ExecuteNonQuery();
                }
                else
                {
                    SqlCommand updateComm = new SqlCommand("UPDATE [dbo].[Table] SET CompanyName=@CompanyName, ContactName=@ContactName, ContactTitle=@ContactTitle, Address=@Address, City=@City, Region=@Region, PostalCode=@PostalCode, Country=@Country, Phone=@Phone WHERE CustomerID=@CustomerID", sqlCon); // Update edited data to DB.
                    updateComm.CommandTimeout = 0;
                    updateComm.Parameters.AddWithValue("@CustomerID", customer.CustomerID);
                    updateComm.Parameters.AddWithValue("@CompanyName", customer.CompanyName ?? "");
                    updateComm.Parameters.AddWithValue("@ContactName", customer.ContactName ?? "");
                    updateComm.Parameters.AddWithValue("@ContactTitle", customer.ContactTitle ?? "");
                    updateComm.Parameters.AddWithValue("@Address", customer.Address ?? "");
                    updateComm.Parameters.AddWithValue("@City", customer.City ?? "");
                    updateComm.Parameters.AddWithValue("@Region", customer.Region ?? "");
                    updateComm.Parameters.AddWithValue("@PostalCode", customer.PostalCode ?? "");
                    updateComm.Parameters.AddWithValue("@Country", customer.Country ?? "");
                    updateComm.Parameters.AddWithValue("@Phone", customer.Phone ?? "");
                    updateComm.ExecuteNonQuery();
                }
            }
            sqlCon.Close();
            return Content("Successfully updated");
        }
        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult Import(ImportRequest importRequest)
        {
            return importRequest.SpreadsheetActions();
        }
        [AcceptVerbs(HttpVerbs.Post)]
        public void ExcelExport(string sheetModel, string sheetData, string password)
        {
            if (String.IsNullOrEmpty(password))
                Spreadsheet.Save(sheetModel, sheetData, "sample", ExportFormat.XLSX, ExcelVersion.Excel2013);
            else
                Spreadsheet.Save(sheetModel, sheetData, "sample", ExportFormat.XLSX, ExcelVersion.Excel2013, password);
        }
        [AcceptVerbs(HttpVerbs.Post)]
        public void CsvExport(string sheetModel, string sheetData)
        {
            Spreadsheet.Save(sheetModel, sheetData, "sample", ExportFormat.CSV);
        }
        [AcceptVerbs(HttpVerbs.Post)]
        public void PdfExport(string sheetModel, string sheetData)
        {
            Spreadsheet.Save(sheetModel, sheetData, "sample", ExportFormat.PDF);
        }
    }
    public class Customer
    {
        public int CustomerID { get; set; }
        public string CompanyName { get; set; }
        public string ContactName { get; set; }
        public string ContactTitle { get; set; }
        public string Address { get; set; }
        public string City { get; set; }
        public string Region { get; set; }
        public string PostalCode { get; set; }
        public string Country { get; set; }
        public string Phone { get; set; }
    }
    public class DataResult
    {
        public IEnumerable<Customer> result { get; set; }
        public int count { get; set; }
    }
    public class UpdateParams
    {
        public List<Customer> Changed { get; set; }
        public string PrimaryKey { get; set; }
    }
}